@@ -350,11 +350,6 @@ def mungeQA(col, txt):
     txt = stripSounds(txt)
     return txt
 
-def applyStyles(widget):
-    p = os.path.join(aqt.mw.pm.base, "style.css")
-    if os.path.exists(p):
-        widget.setStyleSheet(open(p).read())
-
 def openFolder(path):
     if isWin:
         subprocess.Popen(["explorer", "file://"+path])
@@ -523,3 +518,12 @@ class MenuItem:
         a = qmenu.addAction(self.title)
         a.triggered.connect(self.func)
 
+######################################################################
+
+def versionWithBuild():
+    from aqt import appVersion
+    try:
+        from aqt.buildhash import build
+    except:
+        build = "dev"
+    return "%s (%s)" % (appVersion, build)
